@@ -1,8 +1,8 @@
 __appname__ = 'hepai'
-__version__ = '1.1.36'
-__version_suffix__ = 'Beta'  # version suffix, like: 1.0.0-Dev, Beta, Stable
+__version__ = '1.2.8'
+__version_suffix__ = 'Beta'  # version suffix, such as: 1.0.0-Dev, Beta, Stable
 __author__ = 'ZhengDe Zhang'
-__email__ = 'zdzhang@ihep.ac.cn'
+__email__ = 'zdzhang@ihep.ac.cn, xionddb@ihep.ac.cn'
 __backend__ = 'local'
 __affiliation__ = 'CC, IHEP, CAS'
 __supervisor__ = 'FaZhi Qi'
